<?php 
class WCAFW_Option
{
	//rplc: AfterShip, woocommerce-aftership, wcafw, WCAFW
	
	var $company_list;
	var $company_list_by_slug;
	var $option_cache;
	public function __construct()
	{
		
	}
	public function save_options($data)
	{
		update_option('wcafw_options', $data);
	}
	public function save_email_options($data) 
	{
		/* if(isset($data['message']))
			foreach($data['message'] as $index => $content)
			{
				$data['message'][$index] = stripcslashes($content);
			} */
		if(isset($data))
			$data = $this->escape_text($data);
		
		update_option('wcafw_email_options', $data);
	}
	private function escape_text($data)
	{
		foreach($data as $index => $content)
		{
			if(is_string($content))
				$data[$index] = stripcslashes($content);
			else if(is_array($content))
				$data[$index] = $this->escape_text($content);
		}
		return $data;
	}
	public function api_key_has_been_entered()
	{
		$api_key = $this->get_options('api_key');
		if(!isset($api_key) || empty($api_key))
			return false;
		
		return true;
	}
	public function get_options($option_name = null, $default_value = null)
	{
		$result = null;
		
		$options = isset($this->option_cache) ? $this->option_cache : get_option('wcafw_options');
		$this->option_cache = $options;
		if($option_name != null)
		{
			$result = wcafw_get_value_if_set($options, $option_name ,$default_value);
		}
		else 
			$result = $options;
		
		return $result;
	}
	public function get_email_options($option_name = null, $default_value = null)
	{
		global  $wcafw_wpml_model, $wcafw_order_model;
		$result = null;
		
		$options = get_option('wcafw_email_options');
		
		//default values 
		$is_first_run = $options == false || !isset($options) || empty($options);
		$options = $is_first_run ? array() : $options;
		if($is_first_run)
		{
			// -- Email message
			$default_message = __('<h2>Your order has been shipped with [tracking_company_name]</h2>'.
											  '<strong>Tracking code: </strong>[tracking_code]<br/>'.
											  '<a href="[order_url]" target="_blank">Click here</a> to monitor your order status', 'woocommerce-support-ticket-system');
											  
			$langs =  $wcafw_wpml_model->get_langauges_list();
			$options['message'] = array();
			foreach($langs as $lang_data)
			{		
				$options['message'][$lang_data['language_code']] = $default_message;
			}
			
			// -- Active notification
			$default_subject = __('Order #[order_id] has been shipped!', 'woocommerce-support-ticket-system');
			$default_template = __('Hello [billing_first_name] [billing_first_name],<br>'.
							   'The order number [order_id] will be shipped to the following address: [formatted_shipping_address]<br><br>'.
							   '[tracking_message]<br><br>'.
							   '<a href="[order_url]" target="_blank">Click here</a> to monitor your order status.', 'woocommerce-support-ticket-system');
			$default_message = __('<strong>Tracking code: </strong>[tracking_code]<br/>'.
								   'shipped with [tracking_company_name]', 'woocommerce-support-ticket-system');
			
			$options['active_notification'] = array('subject' => array(), 'template'=> array(), 'tracking_message'=> array());
			foreach($langs as $lang_data)
			{					
				$options['active_notification']['subject'][$lang_data['language_code']] = $default_subject;
				$options['active_notification']['template'][$lang_data['language_code']] = $default_template;
				$options['active_notification']['tracking_message'][$lang_data['language_code']] = $default_message;
			}
			
			// -- Position
			$options['position'] = 'woocommerce_email_before_order_table';
			
			// -- Order statuses 
			$statuses = $wcafw_order_model->get_order_statuses();
			$options['order_statuses'] = array();
			foreach ($statuses as $status_code => $status_name)
			{
				$options['order_statuses'][$status_code] = $status_code == 'completed' ? true : false;
			}
		}
		//end default values
		
		//load values
		if($option_name != null)
		{
			$result = wcafw_get_value_if_set($options, $option_name ,$default_value);
		}
		else 
			$result = $options;
		
		return $result;
	}
	public function get_companies_list()
	{
		if(!isset($this->company_list))
		{
			$this->company_list = array_map('str_getcsv', file(WCAFW_PLUGIN_ABS_PATH.'/assets/couriers.csv'));
			$this->company_list_by_slug = array();
			foreach($this->company_list as $company_data)
				$this->company_list_by_slug[$company_data[0]] = $company_data[1];
		}
		return $this->company_list;
	}
	public function get_complete_companies_list()
	{
		$result = array();
		$company_list = $this->get_companies_list();
		
		foreach($company_list as $company_data)
				$result[$company_data[0]] = $company_data[1];
		
		return $result;
	}
	public function get_selected_companies_list()
	{
		$result = array();
		$company_list = $this->get_companies_list();
		$options = $this->get_options();
		
		foreach($company_list as $company_data)
			if( wcafw_get_value_if_set($options, array('selected_company', $company_data[0]), false))
				$result[$company_data[0]] = $company_data[1];
		
		return $result;
	}
	public function get_company_by_name($copany_slug)
	{
		$company_list = $this->get_companies_list();
		return  wcafw_get_value_if_set($this->company_list_by_slug, $copany_slug, $copany_slug);
	}
}
?>