<?php 
class WCAFW_Order
{
	//rplc: AfterShip, woocommerce-aftership, wcafw, WCAFW
	var $aftership;
	function __construct()
	{
		add_action( 'wp_ajax_wcafw_save_data', array( &$this, 'ajax_save_data' ) );
		add_action( 'wp_ajax_wcafw_load_order_timelines', array( &$this, 'ajax_load_order_timelines' ) );
		add_action( 'wp_ajax_wcafw_shortcode_load_order_timelines', array( &$this, 'ajax_shortcode_load_order_timelines' ) );
		add_action( 'wp_ajax_nopriv_wcafw_shortcode_load_order_timelines', array( &$this, 'ajax_shortcode_load_order_timelines' ) );
		add_action('wp_ajax_wcafw_ajax_get_order_tracking_status',array(&$this, 'ajax_get_order_tracking_status'));
		//csv
		add_action('wp_ajax_wcafw_csv_import',array(&$this, 'ajax_import_csv_data'));
	}
	public function ajax_import_csv_data()
	{
		$csv = json_decode(stripslashes($_POST['csv']));
		$merge_data = wcafw_get_value_if_set($_POST, 'merge_data', 'no') == 'yes';
		//wcafw_var_dump($csv);
		if($csv)
		{
			$this->import_from_csv($csv, $merge_data);
		}
		wp_die();
	}
	public function ajax_get_order_tracking_status()
	{
		$status = $this->get_tracking_status($_POST['company_code'], $_POST['tracking_code'], $_POST['order_id']);
		echo $status['status_icon'];
		echo $status['status'];
		wp_die();
	}
	public function ajax_save_data()
	{
		global $wcafw_html_model;
		$data = array();
		parse_str($_POST['serialized_data'], $data);
		
		$this->save_tracking_data($_POST['order_id'], $data['wcafw_tracking_data']);
		
		//render new widges
		$data = $this->get_tracking_data($_POST['order_id']);
		$wcafw_html_model->render_tracking_company_widget($data, $_POST['order_id']);
		wp_die();
	}
	public function ajax_shortcode_load_order_timelines()
	{
		$aftership = $this->init_aftership_service();
		
		if(!wcafw_get_value_if_set($_POST, 'order_id',false))
		{
			_e('Please enter a valid order id', 'woocommerce-aftership');
			wp_die();
		}
		$order_id = trim($_POST['order_id']);
		$tracking_data = $this->get_tracking_data($order_id);
	
		if(empty($tracking_data))
			echo "<p class='wcafw_message'>".__("Order hasn't shipped yet!", 'woocommerce-aftership')."</p>";
		else
			$aftership->render_tracking_info_box($tracking_data, $_POST['lang'], $order_id);
			wp_die();
	}
	public function ajax_load_order_timelines()
	{
		$aftership = $this->init_aftership_service();
		
		if(!wcafw_get_value_if_set($_POST, 'order_id',false))
			wp_die();
		
		$tracking_data = $this->get_tracking_data($_POST['order_id']);
		$aftership->render_tracking_info_box($tracking_data, $_POST['lang'], $_POST['order_id']);
		wp_die();
	}
	private function init_aftership_service()
	{
		global $wcafw_option_model;
		if($this->aftership != null)
			return $this->aftership;
		
		$api_key = $wcafw_option_model->get_options('api_key');
		$this->aftership = new WCAFW_AfterShip($api_key);
		
		return $this->aftership;
	}
	
	public function get_order_statuses($remove_prefix = true)
	{ 
		$statuses = wc_get_order_statuses();
		if($remove_prefix)
		{
			$new_result = array();
			foreach($statuses as $code => $name)
				$new_result[str_replace("wc-","",$code)] = $name;
				
			$statuses = $new_result;
		}
		return $statuses;
	}
	public function get_billing_post_code($order_id)
	{
		$billing_postcode = "";
		$wc_order = wc_get_order($order_id);		
		if(isset($wc_order) && $wc_order != false)
		{
			$billing_postcode = str_replace(" ","", $wc_order->get_billing_postcode());
		}
		
		return $billing_postcode;
	}
	public function get_lang($order)
	{
		global $wcafw_wpml_model;
		
		$wc_order = is_object($order) ? $order : wc_get_order($order);
		$default = $wcafw_wpml_model->get_current_language(); //exameple en;

		if(!isset($order) || $order == false)
			return $default;
		
		$result = $wc_order->get_meta('wpml_language');
		$result = !$result || !is_string($result) || $result == "" ? $default : $result;
		
		return strtolower($result);
	}
	public function import_from_csv($csv, $merge_data)
	{
		if(!isset($csv))
			return;
		
		$output_messages = array();
		$order_statuses = wc_get_order_statuses();
		$allowed_email_notification_statuses = array("send_email_new_order,send_email_cancelled_order",
													 "send_email_customer_processing_order",
													 "send_email_customer_completed_order",
													 "send_email_customer_refunded_order",
													 "send_email_customer_invoice" );
		$columns_names = array("order_id",
								"order_status",
								"force_email_notification",
								"company_id",
								"tracking_code",
								"note");
		
		$colum_index_to_name = $tracking_data = array();
		
		$row = 0;
		foreach($csv as $current_row)
		{
			if(empty($current_row))
					continue;
			
			//setup
			for ($i=0; $i < count($current_row); $i++) 
			{	
				//headers
				if($row == 0)
				{
					foreach($columns_names as $column_name)
						if($column_name == $current_row[$i])
							$colum_index_to_name[$i] = strtolower(trim($column_name));
				}
				//data
				else 
				{
					if(!isset($tracking_data[$row]))
						$tracking_data[$row] = array();
					if(isset($colum_index_to_name[$i]))
					{
						$tracking_data[$row][$colum_index_to_name[$i]] = $current_row[$i];
					}
				}
			}
			$row++;
		}
		
		//save data process
		if(empty($colum_index_to_name))
		{
			echo json_encode(array( 'error_code' => 1,
									'message' => array(__("The file hasn't a valid header row, import process stopped. Please check the csv file structure.", 'woocommerce-aftership'))
									)
							);
			return;
		}
		$row = 0;
		foreach($tracking_data as $row_data)
		{
			$row++;
			$order_id_is_valid = wcafw_get_value_if_set($row_data, 'order_id', false) != false;
			$wc_order = $order_id_is_valid ? wc_get_order($row_data['order_id']) : false;
			$error = false;
			//Error check
			if(!isset($wc_order) || $wc_order == false)
			{
				$output_messages[] =  sprintf(__("Invalid order id for row %d", 'woocommerce-aftership'), $row);
				$error = true;
			}
			else if(wcafw_get_value_if_set($row_data, 'company_id', false) == false)
			{
				$output_messages[] =  sprintf(__("Missing company_id row %d", 'woocommerce-aftership'), $row);
				$error = true;
			}
			else if(wcafw_get_value_if_set($row_data, 'tracking_code', false) == false)
			{
				$output_messages[] =  sprintf(__("Missing tracking_code row %d", 'woocommerce-aftership'), $row);
				$error = true;
			}					
			if($error)
				continue;
			
			//order_status
			if(wcafw_get_value_if_set($row_data, 'order_status', false) != false)
			{
				$wc_order->set_status(str_replace('wc-', '', $row_data['order_status']));
			}
			if(!$merge_data)
			{
				$this->delete_all_tracking_data($row_data['order_id']);
				$old_tracking_data = array();
			}
			else
				$old_tracking_data = $this->get_tracking_data($wc_order);
			
			$unique_id = rand (12312, 9999999);
			$new_data = array(
						$unique_id = array(
							'company_code' => $row_data['company_id'],
							'tracking_code' => $row_data['tracking_code'],
							'note' => wcafw_get_value_if_set($row_data, 'note', "")
						)		
			);
			
			
			$this->save_tracking_data($row_data['order_id'], array_merge($old_tracking_data, $new_data));
			
		}
		
		echo json_encode(array( 'error_code' => 0,
										'message' => $output_messages
										)
								);
	}
	public function get_tracking_status($slug, $tracking_code, $order_id)
	{
		global $wcafw_option_model;
		$aftership = $this->init_aftership_service();
		try{
			$checkpoint = $aftership->get_last_checkpoint($slug, $tracking_code, $order_id);
		}
		catch(Exception $e)
		{
			//wcafw_var_dump($e);
			$checkpoint = array(
					'data' => array(
									'checkpoint' => array('subtag_message' => $e->getMessage()),
									'tag'=>'attemptfail',
								)
			);
		}
		
		//wcafw_var_dump($checkpoint);
		$status = wcafw_get_value_if_set($checkpoint, array('data', 'checkpoint', 'subtag_message'), __('N/A', 'woocommerce-aftership'));
		$message = wcafw_get_value_if_set($checkpoint, array('data', 'checkpoint', 'message'), __('N/A', 'woocommerce-aftership'));	
		$status_icon = '<img class="wcafw_shipping_badge" width="24" style="vertical-align: top;" src="'.WCAFW_PLUGIN_PATH.'/img/aftership/'.strtolower($checkpoint["data"]["tag"]).'.svg"></img>';
		
		return array('status' => $status, 'message'=>$message, 'status_icon' =>$status_icon);
	}
	public function save_tracking_data($order_id, $data)
	{
		global $wcafw_option_model, $wcafw_country_model, $wcafw_email_model;
		$wc_order = wc_get_order($order_id);
		
		if(!$wcafw_option_model->api_key_has_been_entered())
			return;
		
		$old_tracking_data = $this->get_tracking_data($wc_order);
		$aftership = $this->init_aftership_service();
		$active_notification_data = array();
		$billing_postcode = str_replace(" ","", $wc_order->get_billing_postcode());
		
		foreach($data as $tracking_unique_id => $shipping_data)
		{
			$is_update = wcafw_get_value_if_set($shipping_data, 'type', "creation") == 'update';
			//remove spaces
			if(wcafw_get_value_if_set($shipping_data, 'tracking_code', "") != "")
				$shipping_data['tracking_code'] = trim($shipping_data['tracking_code']);
			
			//empty
			if((wcafw_get_value_if_set($shipping_data, 'tracking_code', "") == "" || wcafw_get_value_if_set($shipping_data, 'company_code', "") == "") && !$is_update )
			{
					unset($data[$tracking_unique_id]);
					continue;
			}
			//delete
			if(wcafw_get_value_if_set($shipping_data, 'to_delete', 'no') == 'yes')
			{
				$old_data = wcafw_get_value_if_set($old_tracking_data, $tracking_unique_id, false);
				if($old_data != false)
				{
					try
					{
						if(wcafw_get_value_if_set($old_data, 'tracking_unique_id', false ) != false )
						{
							$aftership->delete_shipping_tracking_by_id(wcafw_get_value_if_set($old_data, 'tracking_unique_id', false )); 
						}
						else
							$aftership->delete_by_slug($old_data);
						
					}catch(Exception $e){/* wcafw_var_dump($e); */};
					unset($data[$tracking_unique_id]);
					//skips the current loop
					continue;
				}
			}
			
			if($is_update)
			{
				//Updata temp metadata. DUE TO SECURITY is prefereable to retrieved from server the already saved data
				$data[$tracking_unique_id]['tracking_code'] = $shipping_data['tracking_code'] = $old_tracking_data[$tracking_unique_id]['tracking_code'];
				$data[$tracking_unique_id]['company_code'] = $shipping_data['company_code'] = $old_tracking_data[$tracking_unique_id]['company_code'];
				
				//clear unuseful index
				unset($data[$tracking_unique_id]['type']);
				unset($data[$tracking_unique_id]['to_delete']);
			}
			
			//$data[$tracking_unique_id]['tracking_postal_code'] =  $billing_postcode;
			$shipping_data['optional_parameters'] = array('tracking_postal_code' => $billing_postcode,
												//'tracking_ship_date' => ,
												//'tracking_account_number' => ,
												//tracking_key =>,
												'tracking_destination_country' => $wc_order->get_billing_country(),
												'tracking_state' => $wc_order->get_billing_state(),
												'tracking_origin_country' => $wcafw_country_model->get_store_base_country(),
												'customer_name' => $wc_order->get_billing_first_name()." ".$wc_order->get_billing_last_name(),
												'order_id' => $wc_order->get_id(),
												'note' => $shipping_data["note"],
												'language' =>  $this->get_lang($wc_order)
												
			);
			
			if($wcafw_option_model->get_options('notification_email', false))
				$shipping_data['optional_parameters']['emails'] = array($wc_order->get_billing_email());
			if($wcafw_option_model->get_options('notification_sms', false))
				$shipping_data['optional_parameters']['smses'] = array($wcafw_country_model->get_area_code_by_country($wc_order->get_billing_country())." ".$wc_order->get_billing_phone());
	
			try{
				$update_tracking_result = $aftership->update_tracking($shipping_data);
				$has_been_created = $update_tracking_result['result'];
				//wcafw_var_dump($update_tracking_result);
				$data[$tracking_unique_id]['tracking_unique_id'] = $update_tracking_result['response']['data']["tracking"]['id'];
			}
			catch(Exception $e){$has_been_created = false;}
			if(!$has_been_created)
			{
				
			} 
			
			//Active notification data
			if(isset($shipping_data['active_notification']))
			{
				$active_notification_data[$tracking_unique_id] = $shipping_data;
			}
		}
		
		//Save
		$wc_order->update_meta_data('_wcafw_tracking', $data);
		$wc_order->save();
		
		//Active notification: send 
		//wcafw_var_dump($active_notification_data);
		if(!empty($active_notification_data))
			$wcafw_email_model->send_active_notification_email_with_tracking_codes($wc_order, $active_notification_data);
	}
	public function delete_all_tracking_data($order_id)
	{
		$data = $this->get_tracking_data($order_id);
		$aftership = $this->init_aftership_service();
		foreach((array)$data as $single_data)
		{
			try{
					$aftership->delete_by_slug($single_data);
				}catch(Exception $e){};
		}
		$wc_order = wc_get_order($order_id);
		if(!isset($wc_order) || $wc_order == false)
			return;
		$wc_order->update_meta_data('_wcafw_tracking', array());
		$wc_order->save();
	}
	public function get_tracking_data($order_id)
	{
		$wc_order = is_object($order_id) ? $order_id : wc_get_order(trim($order_id));
		if(!isset($wc_order) || $wc_order == false)
			return array();
		
		$result = $wc_order->get_meta('_wcafw_tracking');
		
		return isset($result) && is_array($result) ? $result : array();
	}
}
?>